@@ -116,19 +116,19 @@ class Sanitizer:
     parameters are \**kwargs. But only the following are meaningful:
 
     :param list further_arguments: names of arguments that should be
-            passed along with the actual argument in order to return something
-            reasonable. Default: *None*
+        passed along with the actual argument in order to return something
+        reasonable. Default: *None*
     :param bool required: if the argument is required. Default: *False*
-    :param object default: if argument is not given and not
-            :attr:`~Sanitizer.required`, default is returned - even when not
-            :attr:`~Sanitizer.may_change_value`. Note that this value is not
-            passing the sanitizing procedure, so make sure to be able to handle
-            it. Default: *None*
+    :param Any default: if argument is not given and not
+        :attr:`~Sanitizer.required`, default is returned - even when not
+        :attr:`~Sanitizer.may_change_value`. Note that this value is not
+        passing the sanitizing procedure, so make sure to be able to handle
+        it. Default: *None*
     :param bool may_change_value: if the process of sanitizing is allowed
-            to alter *request.options*. If not, the sanitizer can still be used
-            for validation. Default: *True*
+        to alter *request.options*. If not, the sanitizer can still be used
+        for validation. Default: *True*
     :param bool allow_none: if None is allowed and not further validated.
-            Default: *False*
+        Default: *False*
     """
 
     def __init__(self, **kwargs):
@@ -138,7 +138,7 @@ class Sanitizer:
         self.may_change_value = kwargs.get('may_change_value', True)
         self.allow_none = kwargs.get('allow_none', False)
 
-    def sanitize(self, name: str, options: Mapping[str, object]) -> Any:
+    def sanitize(self, name: str, options: Mapping[str, Any]) -> Any:
         """
         Sanitize function. Internally calls _sanitize with the
         correct values and returns the new value (together with a flag
@@ -170,23 +170,23 @@ class Sanitizer:
         except UnformattedValidationError as e:
             self.raise_formatted_validation_error(str(e), name, value, **e.kwargs)
 
-    def _sanitize(self, value: Any, name: str, further_arguments: Mapping[str, object]) -> object:
+    def _sanitize(self, value: Any, name: str, further_arguments: Mapping[str, Any]) -> Any:
         """
         The method where the actual sanitizing takes place.
 
         The standard method just returns *value* so be sure to
         override this method in your Sanitize class.
 
-        :param object value: the value as found in *request.options*.
+        :param Any value: the value as found in *request.options*.
         :param str name: the name of the argument currently
-                sanitized.
+            sanitized.
         :param further_arguments: dictionary
-                holding the values of those additional arguments
-                in *request.options* that are needed for sanitizing.
-                the arguments come straight from the not altered
-                options dict (i.e. before potentially changing
-                sanitizing happened).
-        :type further_arguments: dict[str, object]
+            holding the values of those additional arguments
+            in *request.options* that are needed for sanitizing.
+            the arguments come straight from the not altered
+            options dict (i.e. before potentially changing
+            sanitizing happened).
+        :type further_arguments: dict[str, Any]
         """
         return value
 
@@ -211,7 +211,7 @@ class Sanitizer:
 
         :param str msg: error message
         :param str name: name of the argument
-        :param object value: the argument which caused the error
+        :param Any value: the argument which caused the error
         :param dict \**kwargs: additional arguments for formatting
         """
         format_dict = {'value': value, 'name': name}
@@ -230,7 +230,7 @@ class DictSanitizer(Sanitizer):
 
     :param sanitizers: will be applied to the content of the sanitized dict
     :param bool allow_other_keys: if other keys than those in
-            :attr:`~DictSanitizer.sanitizers` are allowed.
+        :attr:`~DictSanitizer.sanitizers` are allowed.
     :param default_sanitizer: will be applied to the content if no sanitizer is defined
     :type sanitizers: dict[str, Sanitizer]
     :type default_sanitizer: Sanitizer
@@ -243,7 +243,7 @@ class DictSanitizer(Sanitizer):
         self.default_sanitizer = default_sanitizer
         self.allow_other_keys = allow_other_keys
 
-    def _sanitize(self, value: object, name: str, further_arguments: Mapping[str, object]) -> object:
+    def _sanitize(self, value: Any, name: str, further_arguments: Mapping[str, Any]) -> Any:
         if not isinstance(value, dict):
             self.raise_formatted_validation_error(_('Not a "dict"'), name, type(value).__name__)
 
@@ -280,7 +280,7 @@ class ListSanitizer(Sanitizer):
     Plus:
 
     :param sanitizer: sanitizes each of the sanitized list's elements.
-            If *None*, no sanitizing of elements takes place.
+        If *None*, no sanitizing of elements takes place.
     :param int min_elements: must have at least this number of elements
     :param int max_elements: must have at most this number of elements
     :type sanitizer: Sanitizer
@@ -292,7 +292,7 @@ class ListSanitizer(Sanitizer):
         self.min_elements = min_elements
         self.max_elements = max_elements
 
-    def _sanitize(self, value: Any, name: str, further_arguments: Mapping[str, object]) -> object:
+    def _sanitize(self, value: Any, name: str, further_arguments: Mapping[str, Any]) -> Any:
         if not isinstance(value, list):
             self.raise_formatted_validation_error(_('Not a "list"'), name, type(value).__name__)
 
@@ -325,7 +325,7 @@ class BooleanSanitizer(Sanitizer):
     It converts other data types if possible.
     """
 
-    def _sanitize(self, value: Any, name: str, further_arguments: Mapping[str, object]) -> bool:
+    def _sanitize(self, value: Any, name: str, further_arguments: Mapping[str, Any]) -> bool:
         try:
             return bool(value)
         except BaseException:
@@ -342,11 +342,9 @@ class IntegerSanitizer(Sanitizer):
     Plus:
 
     :param int minimum: minimal value allowed
-    :param bool minimum_strict: if the value must be > minimum
-            (>= otherwise)
+    :param bool minimum_strict: if the value must be > minimum (>= otherwise)
     :param int maximum: maximal value allowed
-    :param bool maximum_strict: if the value must be < maximum
-            (<= otherwise)
+    :param bool maximum_strict: if the value must be < maximum (<= otherwise)
     """
 
     def __init__(self, minimum: int | None = None, maximum: int | None = None, minimum_strict: bool | None = None, maximum_strict: bool | None = None, **kwargs: Any) -> None:
@@ -356,7 +354,7 @@ class IntegerSanitizer(Sanitizer):
         self.minimum_strict = minimum_strict
         self.maximum_strict = maximum_strict
 
-    def _sanitize(self, value: Any, name: str, further_arguments: Mapping[str, object]) -> int:
+    def _sanitize(self, value: Any, name: str, further_arguments: Mapping[str, Any]) -> int:
         try:
             value = int(value)
             if not isinstance(value, int):
@@ -401,27 +399,27 @@ class SearchSanitizer(Sanitizer):
     plus:
 
     :param bool add_asterisks: add asterisks at the beginning and the end
-            of the value if needed. Examples:
+        of the value if needed. Examples:
 
-            * "string" -> "\*string*"
-            * "" -> "*"
-            * "string*" -> "string*"
+        * "string" -> "\*string*"
+        * "" -> "*"
+        * "string*" -> "string*"
 
-            Default: True
+        Default: True
     :param int max_number_of_asterisks: An error will be raised if
-            the number of * in the string exceeds this limit. Useful because
-            searching with too many of these patterns in a search query
-            can be very expensive. Note that * from
-            :attr:`~SearchSanitizer.add_asterisks` do count. *None* means an
-            arbitrary number is allowed. Default: 5
+        the number of * in the string exceeds this limit. Useful because
+        searching with too many of these patterns in a search query
+        can be very expensive. Note that * from
+        :attr:`~SearchSanitizer.add_asterisks` do count. *None* means an
+        arbitrary number is allowed. Default: 5
     :param bool use_asterisks: treat asterisks special, i.e. as a
-            substring of arbitrary length. If *False*, it will be escaped as
-            any other character. If *False* the defaults change:
+        substring of arbitrary length. If *False*, it will be escaped as
+        any other character. If *False* the defaults change:
 
-            * :attr:`~SearchSanitizer.add_asterisks` to *False*
-            * :attr:`~SearchSanitizer.max_number_of_asterisks` to *None*.
+        * :attr:`~SearchSanitizer.add_asterisks` to *False*
+        * :attr:`~SearchSanitizer.max_number_of_asterisks` to *None*.
 
-            Default: True
+        Default: True
     '''
 
     def __init__(self, **kwargs):
@@ -437,7 +435,7 @@ class SearchSanitizer(Sanitizer):
     def _escape_and_return(self, value: str) -> str:
         return value
 
-    def _sanitize(self, value: Any, name: str, further_fields: Mapping[str, object]) -> object:
+    def _sanitize(self, value: Any, name: str, further_fields: Mapping[str, Any]) -> Any:
         if value is None:
             value = ''
         value = str(value)
@@ -538,11 +536,11 @@ class StringSanitizer(Sanitizer):
     The input can be validated by a regular expression and by string length
 
     :param regex_pattern: a regex pattern or a string which will be
-            compiled into a regex pattern
+        compiled into a regex pattern
     :type regex_pattern: re.Pattern or str
     :param int re_flags: additional regex flags for the regex_pattern
-            which will be compiled if :attr:`~StringSanitizer.regex_pattern`
-            is a string
+        which will be compiled if :attr:`~StringSanitizer.regex_pattern`
+        is a string
     :param int minimum: the minimum length of the string
     :param int maximum: the maximum length of the string
     :type regex_pattern: str or re._pattern_type
@@ -569,7 +567,7 @@ class StringSanitizer(Sanitizer):
         )
         return new
 
-    def _sanitize(self, value: Any, name: str, further_args: Mapping[str, object]) -> object:
+    def _sanitize(self, value: Any, name: str, further_args: Mapping[str, Any]) -> Any:
         if not isinstance(value, str):
             self.raise_validation_error(_('Value is not a string'))
 
@@ -591,7 +589,7 @@ class DNSanitizer(StringSanitizer):
     Distinguished Name syntax
     """
 
-    def _sanitize(self, value: Any, name: str, further_args: Mapping[str, object]) -> object:
+    def _sanitize(self, value: Any, name: str, further_args: Mapping[str, Any]) -> Any:
         value = super()._sanitize(value, name, further_args)
         try:
             ldap.dn.str2dn(value)
@@ -616,7 +614,7 @@ class ChoicesSanitizer(Sanitizer):
     ChoicesSanitizer makes sure that the input is in a given set of
     choices.
 
-    :param object choices: the allowed choices used.
+    :param Any choices: the allowed choices used.
     """
 
     def __init__(self, choices: Iterable[str], **kwargs: Any) -> None:
@@ -625,7 +623,7 @@ class ChoicesSanitizer(Sanitizer):
         # because list has a different representation than tuple
         self.choices = list(choices)
 
-    def _sanitize(self, value: Any, name: str, further_args: Mapping[str, object]) -> object:
+    def _sanitize(self, value: Any, name: str, further_args: Mapping[str, Any]) -> Any:
         for choice in self.choices:
             if choice == value:
                 # return element from choices
@@ -644,7 +642,7 @@ class MappingSanitizer(ChoicesSanitizer):
     :type mapping: {object : object}
     """
 
-    def __init__(self, mapping: Mapping[str, object], **kwargs: Any) -> None:
+    def __init__(self, mapping: Mapping[str, Any], **kwargs: Any) -> None:
         try:
             # sort allowed values to have reproducible error messages
             # sorted works with every base data type, even inter-data type!
@@ -655,7 +653,7 @@ class MappingSanitizer(ChoicesSanitizer):
         super().__init__(choices, **kwargs)
         self.mapping = mapping
 
-    def _sanitize(self, value: Any, name: str, further_args: Mapping[str, object]) -> object:
+    def _sanitize(self, value: Any, name: str, further_args: Mapping[str, Any]) -> Any:
         value = super()._sanitize(value, name, further_args)
         return self.mapping[value]
 
